GeneratedEntry class final

A generated output event emitted by the build pipeline.

Constructors

GeneratedEntry({required GeneratedEntryType type, required String path, required String content, bool rootRelative = false, bool writeIfMissing = false})
Creates a generated entry descriptor.
const

Properties

content String
Generated file contents.
final
hashCode int
The hash code for this object.
no setterinherited
path String
Output path relative to the selected write base.
final
rootRelative bool
Whether path is relative to the project root instead of the output dir.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type GeneratedEntryType
Generated entry category.
final
writeIfMissing bool
Whether writing should be skipped when the target already exists.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited