GeneratedFile class final

A generated file written during spry build or spry serve.

Constructors

GeneratedFile({required String path, required String content, bool rootRelative = false, bool writeIfMissing = false})
Creates a generated file descriptor.
const

Properties

content String
File contents.
final
hashCode int
The hash code for this object.
no setterinherited
path String
Relative output path.
final
rootRelative bool
Whether path is relative to the project root instead of the output dir.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writeIfMissing bool
Whether writing should be skipped when the file already exists.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited