MiddlewareEntry class final

Metadata for a discovered middleware file.

Constructors

MiddlewareEntry({required String filePath, required String path, HttpMethod? method})
Creates a middleware entry.
const

Properties

filePath String
Absolute file path.
final
hashCode int
The hash code for this object.
no setterinherited
method HttpMethod?
Optional HTTP method restriction.
final
path String
Normalized route scope.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited