RouteScanException class final

Error thrown when route discovery finds an invalid route layout.

Implemented types

Constructors

RouteScanException(String message)
Creates a route scan exception with a human-readable message.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error description.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited