BaseSpryClient class abstract

Minimal runtime base for generated Spry clients.

Constructors

BaseSpryClient({required Uri endpoint, FutureOr<Headers> headers()?})
Creates a client runtime shell.

Properties

endpoint Uri
Base endpoint used by the client.
final
globalHeaders Headers?
Optional static headers applied globally by the generated client.
no setter
hashCode int
The hash code for this object.
no setterinherited
headers FutureOr<Headers> Function()?
Optional runtime headers provider evaluated per request.
final
oxy Oxy
Shared oxy runtime used by generated route helpers.
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited