ClientRoutes class

Shared base for generated route helper types.

Constructors

ClientRoutes(BaseSpryClient client)
Creates a route helper shell bound to a generated client.
const

Properties

client BaseSpryClient
Generated client runtime used by this route helper.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited