ClientRoutes constructor
const
ClientRoutes(
- BaseSpryClient client
Creates a route helper shell bound to a generated client.
Implementation
const ClientRoutes(this.client);
Creates a route helper shell bound to a generated client.
const ClientRoutes(this.client);