OxyConfig class

Constructors

OxyConfig({Uri? baseUrl, HeadersInit? defaultHeaders, Duration connectTimeout = const Duration(seconds: 10), Duration requestTimeout = const Duration(seconds: 30), RedirectPolicy redirectPolicy = RedirectPolicy.follow, int maxRedirects = 5, bool keepAlive = false, RetryPolicy retryPolicy = const RetryPolicy(), HttpErrorPolicy httpErrorPolicy = HttpErrorPolicy.throwException, List<OxyMiddleware> middleware = const [], String userAgent = 'oxy/0.2.0'})
const

Properties

baseUrl Uri?
final
connectTimeout Duration
final
defaultHeaders → HeadersInit?
final
hashCode int
The hash code for this object.
no setterinherited
httpErrorPolicy → HttpErrorPolicy
final
keepAlive bool
final
maxRedirects int
final
middleware List<OxyMiddleware>
final
redirectPolicy → RedirectPolicy
final
requestTimeout Duration
final
retryPolicy → RetryPolicy
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userAgent String
final

Methods

copyWith({Uri? baseUrl, HeadersInit? defaultHeaders, Duration? connectTimeout, Duration? requestTimeout, RedirectPolicy? redirectPolicy, int? maxRedirects, bool? keepAlive, RetryPolicy? retryPolicy, HttpErrorPolicy? httpErrorPolicy, List<OxyMiddleware>? middleware, String? userAgent}) OxyConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited