BuildTarget enum

Supported deployment targets for a Spry application.

Inheritance
Available extensions

Values

vm → const BuildTarget

Runs the application on the Dart VM (dev/serve mode, no compilation).

exe → const BuildTarget

Compiles the application to a native executable using dart compile exe.

aot → const BuildTarget

Compiles the application to an AOT snapshot using dart compile aot-snapshot.

jit → const BuildTarget

Compiles the application to a JIT snapshot using dart compile jit-snapshot.

kernel → const BuildTarget

Compiles the application to a kernel snapshot using dart compile kernel.

node → const BuildTarget

Compiles the application for the Node.js runtime.

bun → const BuildTarget

Compiles the application for the Bun runtime.

deno → const BuildTarget

Compiles the application for the Deno runtime.

cloudflare → const BuildTarget

Compiles the application for the Cloudflare Workers runtime.

vercel → const BuildTarget

Compiles the application for the Vercel runtime.

netlify → const BuildTarget

Compiles the application for the Netlify Functions runtime.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BuildTarget>
A constant List of the values in this enum, in order of their declaration.