SomeErrorThrower.first constructor
SomeErrorThrower.first()
Creates a thrower that rethrows the first tracked error.
Implementation
factory SomeErrorThrower.first() => _BuiltSomeErrorThrower(true);
Creates a thrower that rethrows the first tracked error.
factory SomeErrorThrower.first() => _BuiltSomeErrorThrower(true);