SomeErrorThrower.last constructor
SomeErrorThrower.last()
Creates a thrower that rethrows the last tracked error.
Implementation
factory SomeErrorThrower.last() => _BuiltSomeErrorThrower(false);
Creates a thrower that rethrows the last tracked error.
factory SomeErrorThrower.last() => _BuiltSomeErrorThrower(false);