UnsupportedRuntimeCapabilityError class final

Thrown when application code requires a capability the runtime does not expose.

Inheritance

Constructors

UnsupportedRuntimeCapabilityError(String capability)
Creates an error for an unavailable capability name.

Properties

capability → String
The capability that was requested by application code.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited