NetlifyRuntimeExtension<Request extends Object?> class final

Exposes Netlify Functions host values through RequestContext.extension.

Implemented types

Constructors

NetlifyRuntimeExtension({NetlifyContext? context, Request? request})
Creates a Netlify runtime extension snapshot.
const

Properties

context NetlifyContext?
Netlify's function context for the current invocation.
final
hashCode int
The hash code for this object.
no setterinherited
request → Request?
The host-native request value for the current invocation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited