response property
NodeServerResponseHost?
response
final
The raw Node response writer for the active request, when one exists.
Implementation
final NodeServerResponseHost? response;
The raw Node response writer for the active request, when one exists.
final NodeServerResponseHost? response;