VercelRuntimeExtension<Request extends Object?> class final

Exposes Vercel-specific helpers through RequestContext.extension.

Implemented types

Constructors

VercelRuntimeExtension({VercelFunctions? functions, Request? request})
Creates a Vercel runtime extension snapshot.
const

Properties

functions VercelFunctions?
Vercel helper APIs bound to the current request when available.
final
hashCode int
The hash code for this object.
no setterinherited
request → Request?
The host-native request value for the current invocation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited