File class

File metadata wrapper over Blob.

Inheritance

Constructors

File(Iterable<BlobPart> parts, String name, {String type = '', int? lastModified})

Properties

hashCode int
The hash code for this object.
no setterinherited
lastModified int
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
The size in bytes.
no setterinherited
type String
The media type.
finalinherited

Methods

arrayBuffer() Future<Uint8List>
Returns all bytes.
inherited
bytes() Future<Uint8List>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
slice(int start, [int? end, String? contentType]) Blob
Returns a new Block containing bytes from start (inclusive) to end (exclusive), using Blob-compatible index normalization.
inherited
stream({int chunkSize = 16 * 1024}) Stream<Uint8List>
Streams bytes in chunks.
inherited
text() Future<String>
Returns UTF-8 decoded text.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited