HTTPError class

Base HTTP exception used to convert failures into responses.

Implemented types
Implementers

Constructors

HTTPError(int status, {Object? body, Headers? headers})
Creates an HTTP error with a status, optional body, and headers.
const

Properties

body Object?
Optional response body.
final
hashCode int
The hash code for this object.
no setterinherited
headers Headers?
Optional response headers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
HTTP status code.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toResponse() Response
Converts the error to an HTTP response.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited