NotFoundError class final

Error thrown when no route or fallback matches a request.

Inheritance

Constructors

NotFoundError({required String method, required String path})
Creates a 404 error for an unmatched request.
const

Properties

body Object?
Optional response body.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
headers Headers?
Optional response headers.
finalinherited
method String
Request method.
final
path String
Request path.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
HTTP status code.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toResponse() Response
Converts the error to an HTTP response.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited