Params class

Inheritance

Constructors

Params()

Properties

catchall → String?
no setter
first → (String, String)
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<(String, String)>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last → (String, String)
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → (String, String)
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

add(String name, String value) → void
any(bool test((String, String) element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
call(String name) → String?
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → (String, String)
Returns the indexth element.
inherited
every(bool test((String, String) element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements((String, String) element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test((String, String) element), {(String, String) orElse()?}) → (String, String)
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, (String, String) element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<(String, String)> other) → Iterable<(String, String)>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action((String, String) element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test((String, String) element), {(String, String) orElse()?}) → (String, String)
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement((String, String) e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce((String, String) combine((String, String) value, (String, String) element)) → (String, String)
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
remove(String name, [String? value]) → void
singleWhere(bool test((String, String) element), {(String, String) orElse()?}) → (String, String)
The single element that satisfies test.
inherited
skip(int count) → Iterable<(String, String)>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test((String, String) element)) → Iterable<(String, String)>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<(String, String)>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test((String, String) element)) → Iterable<(String, String)>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<(String, String)>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<(String, String)>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
valuesOf(String name) → Iterable<String>
where(bool test((String, String) element)) → Iterable<(String, String)>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited