Request class

Native request contract shell aligned with the MDN Request surface.

Constructors

Request(Object? input, [RequestInit? init])

Properties

body → Body?
final
bodyUsed bool
no setter
cache → RequestCache
final
credentials → RequestCredentials
final
destination String
final
duplex → RequestDuplex
final
hashCode int
The hash code for this object.
no setterinherited
headers Headers
final
integrity String
final
isHistoryNavigation bool
final
keepalive bool
final
method HttpMethod
final
mode → RequestMode
final
redirect → RequestRedirect
final
referrer String
final
referrerPolicy → RequestReferrerPolicy?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

arrayBuffer() Future<Uint8List>
blob() Future<Blob>
bytes() Future<Uint8List>
clone() Request
formData() Future<FormData>
json<T>() Future<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
text() Future<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited