RuntimeInfo class final

Identifies a runtime family and the role it is performing.

Constructors

RuntimeInfo({required String name, required String kind})
Creates immutable metadata for a runtime instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
kind String
Runtime mode such as server or entry.
final
name String
Stable runtime family name such as dart or node.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited