EventWebSocket class final

Websocket controls and metadata for the active request event.

Constructors

EventWebSocket(Event _event)
Creates a websocket view over the active request event.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isSupported bool
Whether the active runtime family supports websocket upgrades.
no setter
isUpgradeRequest bool
Whether the active request is a websocket upgrade attempt.
no setter
requestedProtocols List<String>
Requested websocket subprotocols from the client handshake.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upgrade(WebSocketHandler handler, {String? protocol}) Response
Accepts the websocket upgrade for the current request.

Operators

operator ==(Object other) bool
The equality operator.
inherited