EventWebSocket constructor
const
EventWebSocket(
- Event _event
Creates a websocket view over the active request event.
Implementation
const EventWebSocket(this._event);
Creates a websocket view over the active request event.
const EventWebSocket(this._event);