WebSocketRequest class abstract interface

Request-scoped websocket upgrade capability exposed by a runtime.

Properties

hashCode int
The hash code for this object.
no setterinherited
isUpgradeRequest bool
Whether the active request is a websocket upgrade attempt.
no setter
requestedProtocols List<String>
The subprotocols requested by the client handshake.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept(WebSocketHandler handler, {String? protocol}) Response
Returns a response-compatible upgrade outcome for Server.fetch(...).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited