isUpgradeRequest property
bool
get
isUpgradeRequest
Whether the active request is a websocket upgrade attempt.
Implementation
bool get isUpgradeRequest;
Whether the active request is a websocket upgrade attempt.
bool get isUpgradeRequest;