app
library
Classes
-
Blob
-
Native detached binary large object.
-
ErrorRoute
-
Binds an error handler to a route path and optional method.
-
File
-
File metadata wrapper over Blob.
-
FormData
-
-
-
MiddlewareRoute
-
Binds middleware to a route path and optional method.
-
Request
-
Native request contract shell aligned with the MDN
Request surface.
-
RequestInit
-
Initialization options for Request, aligned with the MDN Fetch
RequestInit surface.
-
Response
-
-
ResponseInit
-
-
Spry
-
A Spry application with routes, middleware, and error handlers.
-
URLSearchParams
-
Query parameter collection compatible with the MDN URLSearchParams model.
Enums
-
HttpMethod
-
Standard HTTP methods used by both client and server side APIs.
Exceptions / Errors
-
HTTPError
-
Base HTTP exception used to convert failures into responses.
-
NotFoundError
-
Error thrown when no route or fallback matches a request.