HooksEntry class final
Metadata discovered from hooks.dart.
Constructors
- HooksEntry({required String filePath, bool hasOnStart = false, bool hasOnStop = false, bool hasOnError = false})
-
Creates hooks metadata.
const
Properties
- filePath → String
-
Absolute file path.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasOnError → bool
-
Whether
onErroris defined.final - hasOnStart → bool
-
Whether
onStartis defined.final - hasOnStop → bool
-
Whether
onStopis defined.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited