RouteEntry class final

Metadata for a discovered route file.

Constructors

RouteEntry({required String filePath, required String path, required HttpMethod? method, String? wildcardParam, Map<String, Object?>? openapi})
Creates a route entry.
const

Properties

filePath String
Absolute file path.
final
hashCode int
The hash code for this object.
no setterinherited
method HttpMethod?
Optional HTTP method restriction.
final
openapi Map<String, Object?>?
Optional route-level OpenAPI metadata.
final
path String
Normalized route path.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wildcardParam String?
Wildcard parameter name, when present.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited