RouteTree class final
Scanned route metadata used by the generator.
Constructors
-
RouteTree({List<
RouteEntry> routes = const [], List<MiddlewareEntry> globalMiddleware = const [], List<MiddlewareEntry> scopedMiddleware = const [], List<ErrorEntry> scopedErrors = const [], RouteEntry? fallback, HooksEntry? hooks}) -
Creates a scanned route tree.
const
Properties
- fallback → RouteEntry?
-
Optional root fallback route.
final
-
globalMiddleware
→ List<
MiddlewareEntry> -
Global middleware entries.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hooks → HooksEntry?
-
Optional hooks file metadata.
final
-
routes
→ List<
RouteEntry> -
Matched route entries.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopedErrors
→ List<
ErrorEntry> -
Route-scoped error entries.
final
-
scopedMiddleware
→ List<
MiddlewareEntry> -
Route-scoped middleware entries.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited