ScanEntry class final
A scanner event emitted by the scanner.
Constructors
- ScanEntry.fallback(RouteEntry route)
-
Creates a fallback route scan event.
factory
- ScanEntry.globalMiddleware(MiddlewareEntry middleware)
-
Creates a global middleware scan event.
factory
- ScanEntry.hooks(HooksEntry hooks)
-
Creates a hooks scan event.
factory
- ScanEntry.route(RouteEntry route)
-
Creates a route scan event.
factory
- ScanEntry.scopedError(ErrorEntry error)
-
Creates a scoped error scan event.
factory
- ScanEntry.scopedMiddleware(MiddlewareEntry middleware)
-
Creates a scoped middleware scan event.
factory
Properties
- error → ErrorEntry?
-
Error payload when type is ScanEntryType.scopedError.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hooks → HooksEntry?
-
Hooks payload when type is ScanEntryType.hooks.
final
- middleware → MiddlewareEntry?
-
Middleware payload when type represents middleware.
final
- route → RouteEntry?
-
Route payload when type is ScanEntryType.route or fallback.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ScanEntryType
-
Scan event category.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited