Selects which tracked error some(...) should throw after all candidates fail.
Constructors
- SomeErrorThrower.first()
-
Creates a thrower that rethrows the first tracked error.
factory
- SomeErrorThrower.last()
-
Creates a thrower that rethrows the last tracked error.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
throws(
) → Never - Throws the selected error after all candidates fail.
-
toString(
) → String -
A string representation of this object.
inherited
-
track(
Object error, StackTrace stackTrace) → void - Tracks a failed candidate error.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited