Represents a running server hosted by a concrete runtime family.
Properties
- capabilities → RuntimeCapabilities
-
Capabilities exposed by the running runtime instance.
no setter
-
closed
→ Future<
void> -
Completes after the runtime has fully stopped.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- info → RuntimeInfo
-
Static identification for the runtime instance.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → Uri?
-
Network address bound by the runtime when one exists.
no setter
Methods
-
close(
) → Future< void> - Stops the runtime and resolves when shutdown completes.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited