RuntimeStartupError class final

Thrown when a runtime fails during startup or binding.

Inheritance

Constructors

RuntimeStartupError(String message, [Object? cause])
Creates an error describing why runtime startup failed.

Properties

cause Object?
The original error raised by the host, if one exists.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable startup failure details.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited