DartRuntimeExtension class final
Exposes dart:io server objects through RequestContext.extension.
- Implemented types
Constructors
- DartRuntimeExtension({required HttpServer server, HttpRequest? request, HttpResponse? response})
-
Creates a Dart runtime extension snapshot.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- request → HttpRequest?
-
The active
dart:iorequest, when handling a request.final - response → HttpResponse?
-
The active
dart:ioresponse writer, when handling a request.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- server → HttpServer
-
The listening HTTP server for the active runtime.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited