NodeRuntimeExtension class final
Exposes Node-specific host objects through RequestContext.extension.
- Implemented types
Constructors
- NodeRuntimeExtension({NodeProcess? process, NodeHttpServerHost? server, NodeIncomingMessageHost? request, NodeServerResponseHost? response})
-
Creates a Node runtime extension snapshot.
const
- NodeRuntimeExtension.host()
-
Creates a host-level extension before the server starts handling requests.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- process → NodeProcess?
-
The Node
processobject when running on a Node host.final - request → NodeIncomingMessageHost?
-
The raw incoming Node request for the active request, when one exists.
final
- response → NodeServerResponseHost?
-
The raw Node response writer for the active request, when one exists.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- server → NodeHttpServerHost?
-
The active Node HTTP server, when the runtime is serving requests.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited