VercelFunctions class final
Wraps the helper APIs exposed by @vercel/functions.
Properties
- env → Object?
-
Returns environment bindings exposed by the host, when available.
no setter
- geolocation → Object?
-
Returns Vercel geolocation data for the current request, when available.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipAddress → String?
-
Returns the client IP address for the current request, when available.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addCacheTag(
String tag, [List< String> additionalTags = const []]) → Future<void> - Adds one or more cache tags to the current execution context.
-
attachDatabasePool(
Object dbPool) → void - Registers a database pool so the host can manage its lifecycle.
-
dangerouslyDeleteBySrcImage(
String srcImage, {int? revalidationDeadlineSeconds}) → Future< void> - Deletes a cached source image immediately.
-
dangerouslyDeleteByTag(
String tag, {List< String> additionalTags = const [], int? revalidationDeadlineSeconds}) → Future<void> - Deletes one or more cache tags immediately.
-
getCache(
{String? namespace, String? namespaceSeparator, String keyHashFunction(String key)?}) → VercelRuntimeCache - Returns a namespaced Vercel runtime cache facade.
-
invalidateBySrcImage(
String srcImage) → Future< void> - Invalidates a cached source image.
-
invalidateByTag(
String tag, [List< String> additionalTags = const []]) → Future<void> - Invalidates one or more cache tags.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
waitUntil(
Future< void> task) → void -
Schedules background work via Vercel's
waitUntilintegration.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited