VercelRuntimeCache class final
Wraps a Vercel runtime cache namespace.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String key) → Future< void> - Deletes a cached value by key.
-
expireTag(
String tag, [List< String> additionalTags = const []]) → Future<void> - Expires one or more tags within this cache namespace.
-
get(
String key) → Future< Object?> - Retrieves a cached value by key.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
String key, Object? value, {String? name, List< String> ? tags, int? ttl}) → Future<void> -
Stores a value under
key. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited