ErrorRoute class final
Binds an error handler to a route path and optional method.
Constructors
- ErrorRoute({required String path, required ErrorHandler handler, HttpMethod? method})
-
Creates an error route binding.
const
Properties
- handler → ErrorHandler
-
Error handler implementation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → HttpMethod?
-
Optional HTTP method restriction.
final
- path → String
-
Path pattern matched by the error handler.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited