RuntimeInfo class final
Identifies a runtime family and the role it is performing.
Constructors
- RuntimeInfo({required String name, required String kind})
-
Creates immutable metadata for a runtime instance.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited